pub enum PromptMessageContent {
Text {
text: String,
},
Image {
image: Annotated<RawImageContent>,
},
Resource {
resource: Annotated<RawEmbeddedResource>,
},
ResourceLink {
link: Annotated<RawResource>,
},
}Expand description
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc. Content types that can be included in prompt messages
Variants
Text
Plain text content
Image
Image content with base64-encoded data
Fields

image: Annotated<RawImageContent>Resource
Embedded server-side resource
Fields

resource: Annotated<RawEmbeddedResource>ResourceLink
A link to a resource that can be fetched separately
Fields

link: Annotated<RawResource>Implementations
Sourceimpl PromptMessageContent
impl PromptMessageContent
pub fn text(text: impl Into<String>) -> PromptMessageContent
Sourcepub fn resource_link(resource: Annotated<RawResource>) -> PromptMessageContent
pub fn resource_link(resource: Annotated<RawResource>) -> PromptMessageContent
Create a resource link content