pub enum RawContent {
Text(RawTextContent),
Image(RawImageContent),
Resource(RawEmbeddedResource),
Audio(RawAudioContent),
ResourceLink(RawResource),
}Expand description
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc.
Variants
Text(RawTextContent)
Image(RawImageContent)
Resource(RawEmbeddedResource)
Audio(RawAudioContent)
ResourceLink(RawResource)
Implementations
Sourceimpl RawContent
impl RawContent
pub fn json<S>(json: S) -> Result<RawContent, ErrorData>where
S: Serialize,
pub fn text<S>(text: S) -> RawContent
pub fn image<S, T>(data: S, mime_type: T) -> RawContent
pub fn resource(resource: ResourceContents) -> RawContent
pub fn embedded_text<S, T>(uri: S, content: T) -> RawContent
Sourcepub fn as_text(&self) -> Option<&RawTextContent>
pub fn as_text(&self) -> Option<&RawTextContent>
Get the text content if this is a TextContent variant
Sourcepub fn as_image(&self) -> Option<&RawImageContent>
pub fn as_image(&self) -> Option<&RawImageContent>
Get the image content if this is an ImageContent variant
Sourcepub fn as_resource(&self) -> Option<&RawEmbeddedResource>
pub fn as_resource(&self) -> Option<&RawEmbeddedResource>
Get the resource content if this is an ImageContent variant
Sourcepub fn as_resource_link(&self) -> Option<&RawResource>
pub fn as_resource_link(&self) -> Option<&RawResource>
Get the resource link if this is a ResourceLink variant
Sourcepub fn resource_link(resource: RawResource) -> RawContent
pub fn resource_link(resource: RawResource) -> RawContent
Create a resource link content