#[non_exhaustive]pub struct McpAnnotations {
pub audience: Option<Vec<Role>>,
pub priority: Option<f32>,
pub last_modified: Option<DateTime<Utc>>,
}Expand description
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.audience: Option<Vec<Role>>priority: Option<f32>last_modified: Option<DateTime<Utc>>Implementations
Sourceimpl Annotations
impl Annotations
Sourcepub fn for_resource(priority: f32, timestamp: DateTime<Utc>) -> Annotations
pub fn for_resource(priority: f32, timestamp: DateTime<Utc>) -> Annotations
Creates a new Annotations instance specifically for resources optional priority, and a timestamp (defaults to now if None)