pub struct McpCreateElicitationResult {
pub action: ElicitationAction,
pub content: Option<Value>,
pub meta: Option<Meta>,
}Expand description
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc. The result returned by a client in response to an elicitation request.
Contains the user’s decision (accept/decline/cancel) and optionally their input data if they chose to accept the request.
Fields
action: ElicitationActionThe user’s decision on how to handle the elicitation request
content: Option<Value>The actual data provided by the user, if they accepted the request. Must conform to the JSON schema specified in the original request. Only present when action is Accept.
meta: Option<Meta>Optional protocol-level metadata for this result.
Implementations
Sourceimpl CreateElicitationResult
impl CreateElicitationResult
Sourcepub fn new(action: ElicitationAction) -> CreateElicitationResult
pub fn new(action: ElicitationAction) -> CreateElicitationResult
Create a new CreateElicitationResult.
Sourcepub fn with_content(self, content: Value) -> CreateElicitationResult
pub fn with_content(self, content: Value) -> CreateElicitationResult
Set the content on this result.
Sourcepub fn with_meta(self, meta: Meta) -> CreateElicitationResult
pub fn with_meta(self, meta: Meta) -> CreateElicitationResult
Set the metadata on this result.