pub struct McpLoggingMessageNotificationParam {
pub level: LoggingLevel,
pub logger: Option<String>,
pub data: Value,
}Expand description
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc. Parameters for a logging message notification
Fields
level: LoggingLevelThe severity level of this log message
logger: Option<String>Optional logger name that generated this message
data: ValueThe actual log data
Implementations
Sourceimpl LoggingMessageNotificationParam
impl LoggingMessageNotificationParam
Sourcepub fn new(level: LoggingLevel, data: Value) -> LoggingMessageNotificationParam
pub fn new(level: LoggingLevel, data: Value) -> LoggingMessageNotificationParam
Create a new LoggingMessageNotificationParam.
Sourcepub fn with_logger(
self,
logger: impl Into<String>,
) -> LoggingMessageNotificationParam
pub fn with_logger( self, logger: impl Into<String>, ) -> LoggingMessageNotificationParam
Set the logger name.