pub struct McpRawResource {
pub uri: String,
pub name: String,
pub title: Option<String>,
pub description: Option<String>,
pub mime_type: Option<String>,
pub size: Option<u32>,
pub icons: Option<Vec<Icon>>,
pub meta: Option<Meta>,
}Expand description
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc. Represents a resource in the extension with metadata
Fields
uri: StringURI representing the resource location (e.g., “file:///path/to/file” or “str:///content”)
name: StringName of the resource
title: Option<String>Human-readable title of the resource
description: Option<String>Optional description of the resource
mime_type: Option<String>MIME type of the resource content (“text” or “blob”)
size: Option<u32>The size of the raw resource content, in bytes (i.e., before base64 encoding or any tokenization), if known.
This can be used by Hosts to display file sizes and estimate context window us
icons: Option<Vec<Icon>>Optional list of icons for the resource
meta: Option<Meta>Optional additional metadata for this resource
Implementations
Sourceimpl RawResource
impl RawResource
Sourcepub fn new(uri: impl Into<String>, name: impl Into<String>) -> RawResource
pub fn new(uri: impl Into<String>, name: impl Into<String>) -> RawResource
Creates a new Resource from a URI with explicit mime type
Sourcepub fn with_title(self, title: impl Into<String>) -> RawResource
pub fn with_title(self, title: impl Into<String>) -> RawResource
Set the human-readable title.
Sourcepub fn with_description(self, description: impl Into<String>) -> RawResource
pub fn with_description(self, description: impl Into<String>) -> RawResource
Set the description.
Sourcepub fn with_mime_type(self, mime_type: impl Into<String>) -> RawResource
pub fn with_mime_type(self, mime_type: impl Into<String>) -> RawResource
Set the MIME type.
Sourcepub fn with_size(self, size: u32) -> RawResource
pub fn with_size(self, size: u32) -> RawResource
Set the size in bytes.
Sourcepub fn with_icons(self, icons: Vec<Icon>) -> RawResource
pub fn with_icons(self, icons: Vec<Icon>) -> RawResource
Set the icons.
Sourcepub fn with_meta(self, meta: Meta) -> RawResource
pub fn with_meta(self, meta: Meta) -> RawResource
Set the metadata.