#[non_exhaustive]pub struct McpSamplingMessage {
pub role: Role,
pub content: SamplingContent<SamplingMessageContent>,
pub meta: Option<Meta>,
}Expand description
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc. A message in a sampling conversation, containing a role and content.
This represents a single message in a conversation flow, used primarily in LLM sampling requests where the conversation history is important for generating appropriate responses.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.role: RoleThe role of the message sender (User or Assistant)
content: SamplingContent<SamplingMessageContent>The actual content of the message (text, image, audio, tool use, or tool result)
meta: Option<Meta>Implementations
Sourceimpl SamplingMessage
impl SamplingMessage
pub fn new( role: Role, content: impl Into<SamplingMessageContent>, ) -> SamplingMessage
pub fn new_multiple( role: Role, contents: Vec<SamplingMessageContent>, ) -> SamplingMessage
pub fn user_text(text: impl Into<String>) -> SamplingMessage
pub fn assistant_text(text: impl Into<String>) -> SamplingMessage
pub fn user_tool_result( tool_use_id: impl Into<String>, content: Vec<Annotated<RawContent>>, ) -> SamplingMessage
pub fn assistant_tool_use( id: impl Into<String>, name: impl Into<String>, input: Map<String, Value>, ) -> SamplingMessage