#[non_exhaustive]pub struct McpSetLevelRequestParams {
pub meta: Option<Meta>,
pub level: LoggingLevel,
}Expand description
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc. Parameters for setting the logging level
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.meta: Option<Meta>Protocol-level metadata for this request (SEP-1319)
level: LoggingLevelThe desired logging level
Implementations
Sourceimpl SetLevelRequestParams
impl SetLevelRequestParams
Sourcepub fn new(level: LoggingLevel) -> SetLevelRequestParams
pub fn new(level: LoggingLevel) -> SetLevelRequestParams
Create a new SetLevelRequestParams with the given logging level.