pub struct McpToolAdapter { /* private fields */ }Expand description
Adapter exposing an MCP tool as an agentkit Tool.
Implementations
Sourceimpl McpToolAdapter
impl McpToolAdapter
Sourcepub fn new(
server_id: &McpServerId,
connection: Arc<McpConnection>,
tool: McpTool,
) -> Self
pub fn new( server_id: &McpServerId, connection: Arc<McpConnection>, tool: McpTool, ) -> Self
Creates a new tool adapter for the given MCP tool, using the
McpToolNamespace::Default naming strategy.
Sourcepub fn with_namespace(
server_id: &McpServerId,
connection: Arc<McpConnection>,
tool: McpTool,
namespace: &McpToolNamespace,
) -> Self
pub fn with_namespace( server_id: &McpServerId, connection: Arc<McpConnection>, tool: McpTool, namespace: &McpToolNamespace, ) -> Self
Creates a new tool adapter with a custom name-namespacing strategy.