#[non_exhaustive]pub struct PromptArgument {
pub name: String,
pub title: Option<String>,
pub description: Option<String>,
pub required: Option<bool>,
}Expand description
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc. Represents a prompt argument that can be passed to customize the prompt
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the argument
title: Option<String>A human-readable title for the argument
description: Option<String>A description of what the argument is used for
required: Option<bool>Whether this argument is required
Implementations
Sourceimpl PromptArgument
impl PromptArgument
Sourcepub fn new<N>(name: N) -> PromptArgument
pub fn new<N>(name: N) -> PromptArgument
Create a new prompt argument
Sourcepub fn with_title<T>(self, title: T) -> PromptArgument
pub fn with_title<T>(self, title: T) -> PromptArgument
Set the title
Sourcepub fn with_description<D>(self, description: D) -> PromptArgument
pub fn with_description<D>(self, description: D) -> PromptArgument
Set the description
Sourcepub fn with_required(self, required: bool) -> PromptArgument
pub fn with_required(self, required: bool) -> PromptArgument
Set the required flag