pub struct RawAudioContent {
pub data: String,
pub mime_type: String,
}Expand description
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc.
Fields
data: Stringmime_type: StringTrait Implementations
Sourceimpl AnnotateAble for RawAudioContent
impl AnnotateAble for RawAudioContent
fn optional_annotate(self, annotations: Option<Annotations>) -> Annotated<Self>where
Self: Sized,
fn annotate(self, annotations: Annotations) -> Annotated<Self>where
Self: Sized,
fn no_annotation(self) -> Annotated<Self>where
Self: Sized,
fn with_audience(self, audience: Vec<Role>) -> Annotated<Self>where
Self: Sized,
fn with_priority(self, priority: f32) -> Annotated<Self>where
Self: Sized,
fn with_timestamp(self, timestamp: DateTime<Utc>) -> Annotated<Self>where
Self: Sized,
fn with_timestamp_now(self) -> Annotated<Self>where
Self: Sized,
Sourceimpl Clone for RawAudioContent
impl Clone for RawAudioContent
Sourcefn clone(&self) -> RawAudioContent
fn clone(&self) -> RawAudioContent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RawAudioContent
impl Debug for RawAudioContent
Sourceimpl<'de> Deserialize<'de> for RawAudioContent
impl<'de> Deserialize<'de> for RawAudioContent
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RawAudioContent, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RawAudioContent, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RawAudioContent
impl PartialEq for RawAudioContent
Sourcefn eq(&self, other: &RawAudioContent) -> bool
fn eq(&self, other: &RawAudioContent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RawAudioContent
impl Serialize for RawAudioContent
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for RawAudioContent