pub struct RawEmbeddedResource {
pub meta: Option<Meta>,
pub resource: ResourceContents,
}Expand description
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc.
Fields
meta: Option<Meta>Optional protocol-level metadata for this content block
resource: ResourceContentsImplementations
Sourceimpl RawEmbeddedResource
impl RawEmbeddedResource
Sourcepub fn new(resource: ResourceContents) -> RawEmbeddedResource
pub fn new(resource: ResourceContents) -> RawEmbeddedResource
Create a new RawEmbeddedResource.