pub struct StdioTransportFactory { /* private fields */ }Expand description
Factory that spawns a child process and connects via stdin/stdout.
Created from a StdioTransportConfig. Each call to
connect spawns a new child process.
Implementations
Sourceimpl StdioTransportFactory
impl StdioTransportFactory
Sourcepub fn new(config: StdioTransportConfig) -> Self
pub fn new(config: StdioTransportConfig) -> Self
Creates a new factory from the given stdio transport configuration.