AudioContent

Type Alias AudioContent 

pub type AudioContent = Annotated<RawAudioContent>;
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc.

Aliased Type

pub struct AudioContent {
    pub raw: RawAudioContent,
    pub annotations: Option<Annotations>,
}

Fields

raw: RawAudioContentannotations: Option<Annotations>