EmbeddedResource

Type Alias EmbeddedResource 

pub type EmbeddedResource = Annotated<RawEmbeddedResource>;
Re-exports of the rmcp wire-protocol types this crate now surfaces directly instead of wrapping. Pull these in to pattern-match on tool annotations, content blocks, structured tool output, embedded resources, sampling / elicitation requests, progress and log notifications, etc.

Aliased Type

pub struct EmbeddedResource {
    pub raw: RawEmbeddedResource,
    pub annotations: Option<Annotations>,
}

Fields

raw: RawEmbeddedResourceannotations: Option<Annotations>